==> admob-4.14.2-sources.jar: com/yodo1/mas/mediation/admob/Yodo1MasAdMobUtils.java <==
package com.yodo1.mas.mediation.admob;

import android.os.Bundle;
import android.text.TextUtils;

import com.google.android.gms.ads.AdError;
import com.google.android.gms.ads.ResponseInfo;
import com.yodo1.mas.ad.Yodo1MasAdAdapterBase;
import com.google.android.gms.ads.AdValue;

public class Yodo1MasAdMobUtils {

    private static String getAdSource(String adapterClassName) {
        if(TextUtils.isEmpty(adapterClassName) || !adapterClassName.contains(".")) {
            return "";
        }

        String[] array = adapterClassName.split("\\.");
        if(array.length > 1) {
            return array[array.length - 1];
        }
        return "";
    }

    public static String getFormatString(String methodName, String adType, String adUnitId, String adapterClassName) {
        String[] separated = new String[6];
        if (adapterClassName != null) {
            separated = adapterClassName.split("\\.");
        }
        return String.format("method: %s, %s, ad unit id: %s, network name: %s", methodName, adType, adUnitId, separated[4]);
    }

    public static String getAdErrorFormatString(String methodName, String adType, AdError adError) {
        return String.format("method: %s, %s, error: %s", methodName, adType, adError.toString());
    }

    public static String getAdSourceName(ResponseInfo responseInfo) {
        if(responseInfo == null || responseInfo.getLoadedAdapterResponseInfo() == null) {
            return null;
        }

        String adSourceName = responseInfo.getLoadedAdapterResponseInfo().getAdSourceName();
        if(TextUtils.isEmpty(adSourceName)) {
            adSourceName = getAdSource(responseInfo.getLoadedAdapterResponseInfo().getAdapterClassName());
        }
        return adSourceName;
    }

    public static String getAdSourceUnitId(ResponseInfo responseInfo, Yodo1MasAdAdapterBase adAdapterBase) {
        if(responseInfo == null || responseInfo.getLoadedAdapterResponseInfo() == null
                || adAdapterBase == null
                || adAdapterBase.adSource == null) {
            return null;
        }

        String adSourceUnitId = "";
        String adSourceName = adAdapterBase.adSource;
        Bundle credentials = responseInfo.getLoadedAdapterResponseInfo().getCredentials();
        if(adSourceName.toLowerCase().contains("admob")) { // admob
            adSourceUnitId = (adAdapterBase.adNetworkUnitId != null && adAdapterBase.adNetworkUnitId.length() > 0) ? adAdapterBase.adNetworkUnitId : "";
        }
        else if(adSourceName.toLowerCase().contains("applovin")) { //applovin
            return adSourceUnitId;
        }
        else if(credentials.containsKey("placementID")) {   // Liftoff Monetize(Vungle)
            adSourceUnitId = credentials.getString("placementID");
        }
        else if(credentials.containsKey("ad_unit_id")) {    // Mintegral
            adSourceUnitId = credentials.getString("ad_unit_id");
        }
        else if(credentials.containsKey("spotId")) {    // DT Exchange(Fyber)
            adSourceUnitId = credentials.getString("spotId");
        }
        else if(credentials.containsKey("zoneId")) {    //Unity Ads
            adSourceUnitId = credentials.getString("zoneId");
        }
        else if(credentials.containsKey("placementid")) {    //Pangle,InMobi
            adSourceUnitId = credentials.getString("placementid");
        }
        else if(credentials.containsKey("placement_id")) {    //Meta Audience Network(Facebook)
            adSourceUnitId = credentials.getString("placement_id");
        }
        else if(credentials.containsKey("instanceId")) {    //IronSource
            adSourceUnitId = credentials.getString("instanceId");
        }

        if(TextUtils.isEmpty(adSourceUnitId)) { //Default
            adSourceUnitId = credentials.toString();
        }

        return adSourceUnitId;
    }

    public static String getRevenuePrecision(int precisionType) {
        String revenuePrecision = null;
        switch (precisionType) {
            case AdValue.PrecisionType.UNKNOWN:
                revenuePrecision = "unknown";
                break;
            case AdValue.PrecisionType.ESTIMATED:
                revenuePrecision = "estimated";
                break;
            case AdValue.PrecisionType.PUBLISHER_PROVIDED:
                revenuePrecision = "publisher_defined";
                break;
            case AdValue.PrecisionType.PRECISE:
                revenuePrecision = "exact";
                break;
        }
        return revenuePrecision;
    }
}

==> admob-4.17.1-sources.jar: com/yodo1/mas/mediation/admob/Yodo1MasAdMobUtils.java <==
package com.yodo1.mas.mediation.admob;

import android.os.Bundle;
import android.text.TextUtils;

import com.google.android.gms.ads.AdError;
import com.google.android.gms.ads.ResponseInfo;
import com.yodo1.mas.ad.Yodo1MasAdAdapterBase;
import com.google.android.gms.ads.AdValue;

public class Yodo1MasAdMobUtils {

    public static boolean isAdmobMediation(String advertCode) {
        return TextUtils.equals(advertCode, "ADMOB");
    }

    private static String getAdSource(String adapterClassName) {
        if(TextUtils.isEmpty(adapterClassName) || !adapterClassName.contains(".")) {
            return "";
        }

        String[] array = adapterClassName.split("\\.");
        if(array.length > 1) {
            return array[array.length - 1];
        }
        return "";
    }

    public static String getFormatString(String methodName, String adType, String adUnitId, String adSource) {
        return String.format("method: %s, %s, ad unit id: %s, network name: %s", methodName, adType, adUnitId, adSource);
    }

    public static String getAdErrorFormatString(String methodName, String adType, AdError adError) {
        return String.format("method: %s, %s, error: %s", methodName, adType, adError.toString());
    }

    public static String getAdSourceName(ResponseInfo responseInfo) {
        if(responseInfo == null || responseInfo.getLoadedAdapterResponseInfo() == null) {
            return null;
        }

        String adSourceName = responseInfo.getLoadedAdapterResponseInfo().getAdSourceName();
        if(TextUtils.isEmpty(adSourceName)) {
            adSourceName = getAdSource(responseInfo.getLoadedAdapterResponseInfo().getAdapterClassName());
        }
        return adSourceName;
    }

    public static String getAdSourceUnitId(ResponseInfo responseInfo, Yodo1MasAdAdapterBase adAdapterBase) {
        if(responseInfo == null || responseInfo.getLoadedAdapterResponseInfo() == null
                || adAdapterBase == null
                || adAdapterBase.adSource == null) {
            return null;
        }

        String adSourceUnitId = "";
        String adSourceName = adAdapterBase.adSource;
        Bundle credentials = responseInfo.getLoadedAdapterResponseInfo().getCredentials();
        if(adSourceName.toLowerCase().contains("admob")) { // admob
            adSourceUnitId = (adAdapterBase.adNetworkUnitId != null && adAdapterBase.adNetworkUnitId.length() > 0) ? adAdapterBase.adNetworkUnitId : "";
        }
        else if(adSourceName.toLowerCase().contains("applovin")) { //applovin
            return adSourceUnitId;
        }
        else if(credentials.containsKey("placementID")) {   // Liftoff Monetize(Vungle)
            adSourceUnitId = credentials.getString("placementID");
        }
        else if(credentials.containsKey("ad_unit_id")) {    // Mintegral
            adSourceUnitId = credentials.getString("ad_unit_id");
        }
        else if(credentials.containsKey("spotId")) {    // DT Exchange(Fyber)
            adSourceUnitId = credentials.getString("spotId");
        }
        else if(credentials.containsKey("zoneId")) {    //Unity Ads
            adSourceUnitId = credentials.getString("zoneId");
        }
        else if(credentials.containsKey("placementid")) {    //Pangle,InMobi
            adSourceUnitId = credentials.getString("placementid");
        }
        else if(credentials.containsKey("placement_id")) {    //Meta Audience Network(Facebook)
            adSourceUnitId = credentials.getString("placement_id");
        }
        else if(credentials.containsKey("instanceId")) {    //IronSource
            adSourceUnitId = credentials.getString("instanceId");
        }

        if(TextUtils.isEmpty(adSourceUnitId)) { //Default
            adSourceUnitId = credentials.toString();
        }

        return adSourceUnitId;
    }

    public static String getRevenuePrecision(int precisionType) {
        String revenuePrecision = null;
        switch (precisionType) {
            case AdValue.PrecisionType.UNKNOWN:
                revenuePrecision = "unknown";
                break;
            case AdValue.PrecisionType.ESTIMATED:
                revenuePrecision = "estimated";
                break;
            case AdValue.PrecisionType.PUBLISHER_PROVIDED:
                revenuePrecision = "publisher_defined";
                break;
            case AdValue.PrecisionType.PRECISE:
                revenuePrecision = "exact";
                break;
        }
        return revenuePrecision;
    }
}
